@@ -1,8 +1,7 @@
 from pydantic import BaseModel
 from typing_extensions import Self
 
-from lionagi.libs.hash.hash_dict import hash_dict
-from lionagi.utils import UNDEFINED
+from lionagi.utils import UNDEFINED, hash_dict
 
 
 class HashableModel(BaseModel):
